==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hemsida',
'articles' => 'Artiklar',
'articles_auteur' => 'F&ouml;rfattarens artiklar',
'articles_populaires' => 'De mest l&auml;sta artiklarna',
'articles_rubrique' => 'Avdelningens artiklar',
'aucun_article' => 'Det finns ingen artikel p&aring; denna adress',
'aucun_auteur' => 'Det finns ingen f&ouml;rfattare p&aring; denna adress',
'aucun_site' => 'Det finns ingen sajt p&aring; denna adress',
'aucune_breve' => 'Det finns ingen nyhet p&aring; denna adress',
'aucune_rubrique' => 'Det finns ingen avdelning p&aring; denna adress',
'autres' => 'Andra',
'autres_breves' => 'Andra nyheter',
'autres_groupes_mots_clefs' => 'Andra grupper av nyckelord',
'autres_sites' => 'Andra sajter',

// B
'bonjour' => 'Hej',
'breves' => 'Nyheter',

// C
'commenter_site' => 'Kommentera sajten',
'copie_document_impossible' => 'Det g&aring;r inte att kopiera dokumentet',

// D
'date' => 'Datum',
'dernier_ajout' => 'Senaste bidragen',
'dernieres_breves' => 'Senaste nyheterna',
'derniers_articles' => 'Senaste artiklarna',
'derniers_commentaires' => 'Senaste kommentarerna',
'derniers_messages_forum' => 'Senaste forum-meddelandena',
'documents_interdits_forum' => 'Dokument &auml;r inte till&aring;tna i forumet',

// E
'edition_mode_texte' => 'Textversion',
'en_reponse' => 'Svarar p&aring;:',
'en_resume' => 'Sammanfattning',
'envoyer_message' => 'F&ouml;r att skicka ett meddelande',
'espace_prive' => 'Privat del',

// F
'formats_acceptes' => 'Godk&auml;nda format: @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Sajtens hierarki',

// J
'jours' => 'dagar',

// L
'lien_connecter' => 'Logga in',

// M
'meme_auteur' => 'Av samma f&ouml;rfattare',
'meme_rubrique' => 'Inom samma avdelning',
'memes_auteurs' => 'Av samma f&ouml;rfattare',
'message' => 'Meddelande',
'messages_forum' => 'Forum-meddelande',
'messages_recents' => 'Senaste forum-meddelandena',
'mots_clefs' => 'Nyckelord',
'mots_clefs_meme_groupe' => 'Nyckelord i samma grupp',

// N
'navigation' => 'Navigering',
'nom' => 'Namn',
'nouveautes' => 'Nytt',
'nouveautes_web' => 'Nytt p&aring; webben',
'nouveaux_articles' => 'Nya artiklar',
'nouvelles_breves' => 'Nya nyheter',

// P
'page_precedente' => 'f&ouml;reg&aring;ende sida',
'page_suivante' => 'n&auml;sta sida',
'par_auteur' => 'av ',
'participer_site' => 'Du kan ta en aktiv roll i den h&auml;r sajten och skriva dina egna artiklar genom att registrera dig nedan. Du kommer d&aring; genast att f&aring; ett epost med uppgifter som du anv&auml;nder f&ouml;r att logga in p&aring; sajtens privata del.',
'plan_site' => 'Sajtkarta',
'popularite' => 'Popularitet',
'poster_message' => 'F&ouml;r att skicka ett meddelande',
'proposer_site' => 'Du kan f&ouml;resl&aring; en sajt att l&auml;gga till i avdelningen:',

// R
'repondre_article' => 'Svara p&aring; artikeln',
'repondre_breve' => 'Svara p&aring; nyheten',
'repondre_message' => 'Svara p&aring; meddelandet',
'resultats_recherche' => 'S&ouml;k-resultat',
'retour_debut_forums' => 'Tillbaka till forumens b&ouml;rjan',
'rubrique' => 'Avdelning',
'rubriques' => 'Avdelningar',

// S
'signatures_petition' => 'Underskrifter',
'site_realise_avec_spip' => 'Sajten skapad med SPIP',
'sites_web' => 'Websajter',
'sous_rubriques' => 'Underavdelningar',
'spam' => 'Spam',
'suite' => 'forts&auml;tt',
'sur_web' => 'P&aring; webben',
'syndiquer_rubrique' => 'Syndikera avdelning',
'syndiquer_site' => 'Syndikera hela sajten',

// T
'texte_lettre_information' => 'H&auml;r &auml;r sajtens nyhetsbrev',
'texte_lettre_information_2' => 'Det h&auml;r brevet inneh&aring;ller en sammanfattning av de artiklar och nyheter som publicerats sedan ',

// V
'ver_imprimer' => 'Utskrifts-version',
'voir_en_ligne' => 'Se online',
'voir_squelette' => 'visa sidans mall'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hemsida',
'article' => 'Article', # NEW
'articles' => 'Artiklar',
'articles_auteur' => 'F&ouml;rfattarens artiklar',
'articles_populaires' => 'De mest l&auml;sta artiklarna',
'articles_rubrique' => 'Avdelningens artiklar',
'aucun_article' => 'Det finns ingen artikel p&aring; denna adress',
'aucun_auteur' => 'Det finns ingen f&ouml;rfattare p&aring; denna adress',
'aucun_site' => 'Det finns ingen sajt p&aring; denna adress',
'aucune_breve' => 'Det finns ingen nyhet p&aring; denna adress',
'aucune_rubrique' => 'Det finns ingen avdelning p&aring; denna adress',
'auteur' => 'Auteur', # NEW
'autres' => 'Andra',
'autres_breves' => 'Andra nyheter',
'autres_groupes_mots_clefs' => 'Andra grupper av nyckelord',
'autres_sites' => 'Andra sajter',

// B
'bonjour' => 'Hej',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Nyheter',

// C
'commenter_site' => 'Kommentera sajten',
'copie_document_impossible' => 'Det g&aring;r inte att kopiera dokumentet',

// D
'date' => 'Datum',
'dernier_ajout' => 'Senaste bidragen',
'dernieres_breves' => 'Senaste nyheterna',
'derniers_articles' => 'Senaste artiklarna',
'derniers_commentaires' => 'Senaste kommentarerna',
'derniers_messages_forum' => 'Senaste forum-meddelandena',
'documents_interdits_forum' => 'Dokument &auml;r inte till&aring;tna i forumet',

// E
'edition_mode_texte' => 'Textversion',
'en_reponse' => 'Svarar p&aring;:',
'en_resume' => 'Sammanfattning',
'envoyer_message' => 'F&ouml;r att skicka ett meddelande',
'espace_prive' => 'Privat del',

// F
'formats_acceptes' => 'Godk&auml;nda format: @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Sajtens hierarki',

// J
'jours' => 'dagar',

// L
'lien_connecter' => 'Logga in',

// M
'meme_auteur' => 'Av samma f&ouml;rfattare',
'meme_rubrique' => 'Inom samma avdelning',
'memes_auteurs' => 'Av samma f&ouml;rfattare',
'message' => 'Meddelande',
'messages_forum' => 'Forum-meddelande',
'messages_recents' => 'Senaste forum-meddelandena',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Nyckelord',
'mots_clefs_meme_groupe' => 'Nyckelord i samma grupp',

// N
'navigation' => 'Navigering',
'nom' => 'Namn',
'nouveautes' => 'Nytt',
'nouveautes_web' => 'Nytt p&aring; webben',
'nouveaux_articles' => 'Nya artiklar',
'nouvelles_breves' => 'Nya nyheter',

// P
'page_precedente' => 'f&ouml;reg&aring;ende sida',
'page_suivante' => 'n&auml;sta sida',
'par_auteur' => 'av ',
'participer_site' => 'Du kan ta en aktiv roll i den h&auml;r sajten och skriva dina egna artiklar genom att registrera dig nedan. Du kommer d&aring; genast att f&aring; ett epost med uppgifter som du anv&auml;nder f&ouml;r att logga in p&aring; sajtens privata del.',
'plan_site' => 'Sajtkarta',
'popularite' => 'Popularitet',
'poster_message' => 'F&ouml;r att skicka ett meddelande',
'proposer_site' => 'Du kan f&ouml;resl&aring; en sajt att l&auml;gga till i avdelningen:',

// R
'repondre_article' => 'Svara p&aring; artikeln',
'repondre_breve' => 'Svara p&aring; nyheten',
'repondre_message' => 'Svara p&aring; meddelandet',
'resultats_recherche' => 'S&ouml;k-resultat',
'retour_debut_forums' => 'Tillbaka till forumens b&ouml;rjan',
'rubrique' => 'Avdelning',
'rubriques' => 'Avdelningar',

// S
'signatures_petition' => 'Underskrifter',
'site_realise_avec_spip' => 'Sajten skapad med SPIP',
'sites_web' => 'Websajter',
'sous_rubriques' => 'Underavdelningar',
'spam' => 'Spam',
'suite' => 'forts&auml;tt',
'sur_web' => 'P&aring; webben',
'syndiquer_rubrique' => 'Syndikera avdelning',
'syndiquer_site' => 'Syndikera hela sajten',

// T
'texte_lettre_information' => 'H&auml;r &auml;r sajtens nyhetsbrev',
'texte_lettre_information_2' => 'Det h&auml;r brevet inneh&aring;ller en sammanfattning av de artiklar och nyheter som publicerats sedan ',

// V
'ver_imprimer' => 'Utskrifts-version',
'voir_en_ligne' => 'Se online',
'voir_squelette' => 'visa sidans mall'
);

?>
